"""
Auto-generated media resource.

DO NOT EDIT THIS FILE MANUALLY.
Run `python scripts/generate_resources.py` to regenerate.
"""

from __future__ import annotations

from typing import TYPE_CHECKING, Any

if TYPE_CHECKING:
    from ..client.base import BaseClient


class MediaResource:
    """
    Upload and manage media files.
    """

    def __init__(self, client: BaseClient) -> None:
        self._client = client

    def _build_params(self, **kwargs: Any) -> dict[str, Any]:
        """Build query parameters, filtering None values."""

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        return {to_camel(k): v for k, v in kwargs.items() if v is not None}

    def _build_payload(self, **kwargs: Any) -> dict[str, Any]:
        """Build request payload, filtering None values."""
        from datetime import datetime

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        result: dict[str, Any] = {}
        for k, v in kwargs.items():
            if v is None:
                continue
            if isinstance(v, datetime):
                result[to_camel(k)] = v.isoformat()
            else:
                result[to_camel(k)] = v
        return result

    def get_media_presigned_url(
        self, filename: str, content_type: str, *, size: int | None = None
    ) -> dict[str, Any]:
        """Get a presigned URL for direct file upload (up to 5GB)"""
        payload = self._build_payload(
            filename=filename,
            content_type=content_type,
            size=size,
        )
        return self._client._post("/v1/media/presign", data=payload)

    async def aget_media_presigned_url(
        self, filename: str, content_type: str, *, size: int | None = None
    ) -> dict[str, Any]:
        """Get a presigned URL for direct file upload (up to 5GB) (async)"""
        payload = self._build_payload(
            filename=filename,
            content_type=content_type,
            size=size,
        )
        return await self._client._apost("/v1/media/presign", data=payload)
